@@ -1,12 +1,13 @@
 """
     Implement core capabilities for classes.
 """
-__all__ = ['const', 'dicts', 'auth', 'UserKey', 'APIKeyUser', 'StreamUser', 'StreamResponse']
+__all__ = ['const', 'dicts', 'auth', 'UserKey', 'APIKeyUser', 'StreamUser', 'StreamResponse', 'SnapshotFiles']
 
 from .__version__ import __version__
 from .auth.userkey import (UserKey)
 from .apikeyuser import (APIKeyUser)
 from .streamuser import (StreamUser)
 from .stream_response import (StreamResponse)
+from .tools.files import (SnapshotFiles)
 
 version = __version__
